@@ -552,6 +552,11 @@ table, th, td {{
                 log.debug("Creating experiment folder %s.", self.runtitle_safe)
                 machine.run_command(f"EXP:NEW {self.runtitle_safe} {TEMPLATE_NAME}")
 
+                log.debug("Setting up experiment.xml")
+                self.runstarttime = datetime.now()
+                self.runstate = "RUNNING"
+                self._update_files()
+
                 log.debug("Populating experiment folder.")
                 self._populate_folder(machine)
 
@@ -645,10 +650,38 @@ table, th, td {{
         with machine.ensured_connection(AccessLevel.Observer):
             return self._ensure_running(machine)
 
+    @classmethod
+    def _from_running_via_sync(
+        cls, machine: MachineReference, include_tiffs: bool = False
+    ) -> "Experiment":
+        exp = cls(_create_xml=False)
+
+        p = Path(exp._dir_eds)
+        p.mkdir(parents=True)
+
+        machine = exp._ensure_machine(machine)
+
+        with machine.ensured_connection():
+            crt: str | None = machine.current_run_name
+
+            if not crt:
+                raise ValueError("Nothing is currently running.")
+
+            exp.name = crt
+
+            exp.sync_from_machine(
+                machine, log_method="copy", include_tiffs=include_tiffs
+            )
+
+            exp._update_from_files()
+
+        return exp
+
     def sync_from_machine(
         self,
         machine: MachineReference | None = None,
         log_method: Literal["copy", "eval"] = "eval",
+        include_tiffs: bool = False,
     ) -> None:
         """
         Try to synchronize the data in the experiment to the current state of the run on a
@@ -664,18 +697,24 @@ table, th, td {{
 
             # Transfer anything we don't have
             for f in machine_files:
-                name = os.path.basename(f["path"])
+                name: str = os.path.basename(f["path"])
+
+                if name.lower().endswith("tiff") and not include_tiffs:
+                    continue
+
                 sdspath = self._sdspath(
                     re.sub(".*/apldbio/sds/(.*)$", r"\1", f["path"])
                 )
-                logging.debug(f"checking {f['path']} mtime {f['mtime']} to {sdspath}")
+                log.debug(f"checking {f['path']} mtime {f['mtime']} to {sdspath}")
                 if os.path.exists(sdspath) and os.path.getmtime(sdspath) >= float(
                     f["mtime"]
                 ):
-                    logging.debug(f"{sdspath} has {os.path.getmtime(sdspath)}")
+                    log.debug(f"{sdspath} has {os.path.getmtime(sdspath)}")
                     continue
                 from pathlib import Path  # FIXME
 
+                log.info(f"Updating {sdspath}")
+
                 ldir = f["path"].split("/")[-2]
                 if ldir != "sds":
                     cp = Path(self._dir_eds) / ldir
@@ -762,6 +801,10 @@ table, th, td {{
                 "${LogFolder}/tcprotocol.xml",
                 open(self._sdspath("tcprotocol.xml"), "rb").read(),
             )
+            machine.write_file(
+                "${LogFolder}/qsl-tcprotocol.xml",
+                open(self._sdspath("qsl-tcprotocol.xml"), "rb").read(),
+            )
 
     def change_protocol(
         self,
@@ -827,9 +870,16 @@ table, th, td {{
                 "${LogFolder}/tcprotocol.xml",
                 open(self._sdspath("tcprotocol.xml"), "rb").read(),
             )
+            machine.write_file(
+                "${LogFolder}/qsl-tcprotocol.xml",
+                open(self._sdspath("qsl-tcprotocol.xml"), "rb").read(),
+            )
 
     def save_file(
-        self, file: str | os.PathLike[str] | IO[bytes], overwrite: bool = False
+        self,
+        path_or_stream: str | os.PathLike[str] | IO[bytes] = ".",
+        overwrite: bool = False,
+        update_files: bool = True,
     ) -> None:
         """
         Save an EDS file of the experiment. This *should* be readable by AB's software,
@@ -838,10 +888,15 @@ table, th, td {{
 
         Parameters
         ----------
-        file : str or IO[bytes]
-            A filename or open binary IO.
+        path_or_stream : str or os.PathLike[str] or IO[bytes]
+            A filename, open binary IO, or directory.  If a directory, the file will
+            be saved with the name from `Experiment.runtitle_safe`.
         overwrite : bool, optional
             If True, overwrite any existing file without warning. Defaults to False.
+        update_files: bool, optional
+            If True (default), update files before saving. Use False if you don't want
+            qslib to touch the files, for example, if you have just loaded a run from
+            the machine and don't want qslib to change anything based on its interpretation.
         """
         mode: Literal["w", "x"]
         if overwrite:
@@ -849,42 +904,42 @@ table, th, td {{
         else:
             mode = "x"
 
-        self._update_files()
+        if update_files:
+            self._update_files()
 
-        with zipfile.ZipFile(file, mode) as z:
-            for root, _, files in os.walk(self._dir_base):
-                for file in files:
-                    fpath = os.path.join(root, file)
-                    z.write(fpath, os.path.relpath(fpath, self._dir_base))
-
-    def save_file_without_changes(
-        self, file: str | IO[bytes], overwrite: bool = False
-    ) -> None:
-        """
-        Save an EDS file of the experiment. Unlike :any:`save_file`, this will not
-        update any parts of the file, so if it has not been modified elsewhere,
-        it will be the same as when it was loaded. By default, this will refuse to
-        overwrite an existing file.
-
-        Parameters
-        ----------
-        file : str or IO[bytes]
-            A filename or open binary IO.
-        overwrite : bool, optional
-            If True, overwrite any existing file without warning. Defaults to False.
-        """
-        mode: Literal["w", "x"]
-        if overwrite:
-            mode = "w"
+        if isinstance(path_or_stream, IO):
+            path: Union[Path, IO] = path_or_stream
         else:
-            mode = "x"
+            path = Path(path_or_stream)
+            if path.is_dir():
+                path = (path / self.runtitle_safe).with_suffix(".eds")
 
-        with zipfile.ZipFile(file, mode) as z:
+        with zipfile.ZipFile(path, mode) as z:
             for root, _, files in os.walk(self._dir_base):
                 for file in files:
                     fpath = os.path.join(root, file)
                     z.write(fpath, os.path.relpath(fpath, self._dir_base))
 
+    # def save_file_without_changes(
+    #     self, path: str | os.PathLike[str] | IO[bytes], overwrite: bool = False
+    # ) -> None:
+    #     """
+    #     Save an EDS file of the experiment. Unlike :any:`save_file`, this will not
+    #     update any parts of the file, so if it has not been modified elsewhere,
+    #     it will be the same as when it was loaded. By default, this will refuse to
+    #     overwrite an existing file.
+
+    #     Parameters
+    #     ----------
+    #     path_or_stream : str or os.PathLike[str] or IO[bytes]
+    #         A filename, open binary IO, or directory.  If a directory, the file will
+    #         be saved with the name from `Experiment.runtitle_safe`.
+    #     overwrite : bool, optional
+    #         If True, overwrite any existing file without warning. Defaults to False.
+    #     """
+
+    #     return self.save_file(path, overwrite, update_files=False)
+
     @property
     def sample_wells(self) -> dict[str, list[str]]:
         """A dictionary of sample names to sample wells (convenience read/write access to the :class:`PlateSetup` ."""
@@ -1452,7 +1507,7 @@ table, th, td {{
                 msglog,
                 re.DOTALL | re.MULTILINE,
             ):
-                # We can get the prot name too, and sample volume!
+                # We can get the prot name too, and sample volume! FIXME: not from qslib runs!
                 rp = re.search(
                     r"NEXT RP (?:-CoverTemperature=(?P<ct>[\d.]+) )?(?:-SampleVolume=(?P<sv>[\d.]+) )?([\w-]+) (?P<protoname>[\w-]+)",
                     msglog,
@@ -1469,6 +1524,19 @@ table, th, td {{
                         SCPICommand.from_string(f"PROT unknown_name {m[1]}")
                     )
                 self._protocol_from_log = prot
+
+                # Now that we know the protocol name, we can search for whether the protocol was changed later:
+                for mm in re.finditer(
+                    r"^Debug.*<quote.message>C:.* (PROT[ O].*\n(c:.*\n)+.*)</quote.message>",
+                    msglog,
+                    re.MULTILINE,
+                ):
+                    newprot = Protocol.from_scpicommand(
+                        SCPICommand.from_string(mm[1].replace("\nc:", "\n"))
+                    )
+                    # if newprot.name == prot.name:
+                    self._protocol_from_log = newprot
+
             else:
                 self._protocol_from_log = None
         except ValueError:
